@@ -2,7 +2,14 @@
 URL conf for django-sphinxdoc.
 
 """
-from django.conf.urls.defaults import patterns, url
+
+# Django <= 1.5
+try:
+    from django.conf.urls.defaults import patterns, url
+# Django >= 1.6
+except ImportError:
+    from django.conf.urls import patterns, url
+
 from django.views.generic import ListView
 
 from sphinxdoc import models
@@ -14,6 +21,7 @@ urlpatterns = patterns('sphinxdoc.views',
         r'^$',
         ListView.as_view(
             queryset=models.Project.objects.all().order_by('name')),
+        name='docs-list',
     ),
     url(
         r'^(?P<slug>[\w-]+)/search/$',
@@ -39,6 +47,12 @@ urlpatterns = patterns('sphinxdoc.views',
         {'path': ''},
         name='doc-index',
     ),
+    url(
+        r'^(?P<slug>[\w-]+)/genindex/$',
+        'documentation',
+        {'path': 'genindex'},
+        name='doc-genindex',
+    ),
     url(
         r'^(?P<slug>[\w-]+)/(?P<path>.+)/$',
         'documentation',
